#!/usr/bin/env node
"use strict";
// TODO This is current work in progress
// - Install latest releases of Joi (14,15,16,17) and allow to pick one
// - Add support for HTML page generation with results and JS controls
// - Add support for extended outputs (plain, YAML, Burp, ZAP, ...)
// - Possible to create standalone version for browser usage?
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const _ = require("lodash");
const yargs = require("yargs");
const output_1 = require("./output");
const payload_1 = require("./payload");
function scanCode(filePath, options) {
    if (!filePath) {
        throw new Error(`File containing the Joi validation schema must be provided`);
    }
    if (!['console', 'web'].includes(options.outputFormat)) {
        throw new Error(`Output format ${options.outputFormat} not supported`);
    }
    let fileContent = '';
    try {
        fileContent = fs_1.readFileSync(filePath).toString();
    }
    catch (err) {
        throw new Error(`File containing the Joi validation schema not readable (${err.message})`);
    }
    const schema = eval(`const Joi = require('@hapi/joi');${fileContent}`);
    const basePayload = payload_1.generatePayload(schema);
    // ----
    const validMock = basePayload.generateMock();
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const { value, error } = schema.validate(validMock);
    if (error) {
        console.log(value);
        console.log(error);
        throw new Error('Expecting generated mock to pass the Joi validation schema but failed');
    }
    // ------------
    const generatedAttacks = basePayload.generateAttacks();
    const resultBag = new output_1.ResultBag();
    for (const attack of generatedAttacks) {
        if (attack.tags && _.intersection(attack.tags, options.ignore).length > 0) {
            continue;
        }
        const { error } = schema.validate(attack.payload);
        resultBag.addResult({
            result: error ? 'blocked' : 'bypassed',
            severity: attack.severity,
            messages: attack.messages,
            payload: attack.payload,
            tags: attack.tags || []
        });
    }
    if (options.outputFormat === 'console') {
        const output = new output_1.ConsoleFormat(resultBag).process();
        console.log(output);
    }
    else if (options.outputFormat === 'web') {
        const output = new output_1.WebFormat(resultBag).process();
        console.log(output);
    }
}
yargs
    .command({
    command: 'scan <file> [--ignore=phone,markdown] [--output=console]',
    aliases: ['s'],
    builder: (yargs) => {
        return yargs
            .positional('file', {
            describe: 'JS file containing a Joi schema',
            type: 'string'
        })
            .option('ignore', {
            describe: 'Ignore comma-separated attack tags',
            default: '',
            type: 'string'
        })
            .option('output', {
            describe: 'Output format for attack results',
            choices: ['console', 'web'],
            default: 'console',
            type: 'string'
        });
    },
    handler: (argv) => {
        try {
            scanCode(`${argv.file}`, {
                outputFormat: _.isString(argv.output) ? argv.output : 'console',
                ignore: _.isString(argv.ignore) && argv.ignore.length > 0 ? argv.ignore.split(',') : []
            });
            process.exit(0);
        }
        catch (err) {
            console.log();
            console.log(err.message);
            console.log();
            process.exit(1);
        }
    }
})
    .showHelpOnFail(true)
    .demandCommand()
    .argv;
