"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const _ = require("lodash");
const severity_level_1 = require("../severity-level");
const base_format_1 = require("./base-format");
class ConsoleFormat extends base_format_1.BaseFormat {
    constructor(resultBag) {
        super();
        this.resultBag = resultBag;
    }
    process() {
        const results = _.chain(this.resultBag.records)
            .filter(record => record.result === 'bypassed')
            .orderBy(['severity'])
            .groupBy(record => record.messages[0])
            .toPairs()
            .value();
        let output = '';
        for (const [firstMessage, records] of results) {
            output += `${this.formatLevel(records[0].severity)} ${chalk.whiteBright(firstMessage)} ${chalk.grey(`(${records.length} payloads bypassed)`)}\r\n`;
            const allTags = _.chain(records.map(record => record.tags)).flatten().uniq().value();
            if (allTags.length > 0) {
                output += `#${allTags}\r\n`;
            }
            output += `\r\n`;
            for (const record of records) {
                output += `${chalk.yellow(JSON.stringify(record.payload, null, '  '))}\r\n`;
            }
            output += `\r\n`;
        }
        const analytics = _.countBy(this.resultBag.records, record => record.result);
        output += `Blocked attacks   ${analytics['blocked'] || 0}\r\n`;
        output += `Bypassed attacks  ${analytics['bypassed'] || 0}`;
        output += `\r\n`;
        return output;
    }
    formatLevel(level) {
        if (level === severity_level_1.SeverityLevel.CRITICAL) {
            return chalk.bgRedBright('CRITICAL');
        }
        if (level === severity_level_1.SeverityLevel.HIGH) {
            return chalk.bgRedBright('HIGH');
        }
        if (level === severity_level_1.SeverityLevel.MEDIUM) {
            return chalk.bgGreen('MEDIUM');
        }
        if (level === severity_level_1.SeverityLevel.LOW) {
            return chalk.bgGreen('LOW');
        }
        if (level === severity_level_1.SeverityLevel.INFO) {
            return chalk.bgBlue('INFO');
        }
        return '';
    }
}
exports.ConsoleFormat = ConsoleFormat;
