"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const severity_level_1 = require("../severity-level");
const base_format_1 = require("./base-format");
class WebFormat extends base_format_1.BaseFormat {
    constructor(resultBag) {
        super();
        this.resultBag = resultBag;
    }
    process() {
        const results = _.chain(this.resultBag.records)
            .filter(record => record.result === 'bypassed')
            .orderBy(['severity'])
            .groupBy(record => record.messages[0])
            .toPairs()
            .value();
        let output = '<!DOCTYPE><html><body>';
        for (const [firstMessage, records] of results) {
            output += `<b>${this.formatLevel(records[0].severity)} ${firstMessage}</b> (${records.length} payloads bypassed)}<br>`;
            output += `\r\n`;
            for (const record of records) {
                output += `<pre>${JSON.stringify(record.payload, null, '  ')}</pre>`;
            }
            output += `\r\n`;
        }
        return `${output}</body></html>`;
    }
    formatLevel(level) {
        if (level === severity_level_1.SeverityLevel.CRITICAL) {
            return 'CRITICAL';
        }
        if (level === severity_level_1.SeverityLevel.HIGH) {
            return 'HIGH';
        }
        if (level === severity_level_1.SeverityLevel.MEDIUM) {
            return 'MEDIUM';
        }
        if (level === severity_level_1.SeverityLevel.LOW) {
            return 'LOW';
        }
        if (level === severity_level_1.SeverityLevel.INFO) {
            return 'INFO';
        }
        return '';
    }
}
exports.WebFormat = WebFormat;
