"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const attack_1 = require("../attack");
const base_payload_1 = require("./base-payload");
var NumberConstraint;
(function (NumberConstraint) {
    // Type constraints
    NumberConstraint["integer"] = "integer";
    NumberConstraint["precision"] = "precision";
    // Range constraints
    NumberConstraint["greater"] = "greater";
    NumberConstraint["less"] = "less";
    NumberConstraint["max"] = "max";
    NumberConstraint["min"] = "min";
    NumberConstraint["negative"] = "negative";
    NumberConstraint["positive"] = "positive";
    NumberConstraint["unsafe"] = "unsafe";
    // Strict constraints
    NumberConstraint["multiple"] = "multiple";
    NumberConstraint["port"] = "port";
    NumberConstraint["sign"] = "sign";
})(NumberConstraint || (NumberConstraint = {}));
class NumberPayload extends base_payload_1.BasePayload {
    getKind() {
        return 'number';
    }
    buildFromSchema(rawSchema) {
        if (!rawSchema._rules) {
            return this;
        }
        const allowedConstraints = Object.values(NumberConstraint);
        for (const stringRule of rawSchema._rules) {
            if (!allowedConstraints.includes(stringRule.name)) {
                continue;
            }
            if (stringRule.name === NumberConstraint.min) {
                this.addConstraint({ name: NumberConstraint.min, details: { limit: stringRule.args.limit } });
            }
            else if (stringRule.name === NumberConstraint.max) {
                this.addConstraint({ name: NumberConstraint.max, details: { limit: stringRule.args.limit } });
            }
            else {
                this.addConstraint({ name: stringRule.name });
            }
        }
        return this;
    }
    generateMock() {
        if (this.hasConstraint(NumberConstraint.max)) {
            return this.getConstraint(NumberConstraint.max).limit - 1;
        }
        if (this.hasConstraint(NumberConstraint.less)) {
            return this.getConstraint(NumberConstraint.less).limit - 1;
        }
        if (this.hasConstraint(NumberConstraint.min)) {
            return this.getConstraint(NumberConstraint.min).limit + 1;
        }
        if (this.hasConstraint(NumberConstraint.greater)) {
            return this.getConstraint(NumberConstraint.greater).limit + 1;
        }
        if (this.hasConstraint(NumberConstraint.negative)) {
            return this.getConstraint(NumberConstraint.min).limit + 1;
        }
        return this.hasConstraint(NumberConstraint.negative) ? -5 : 5;
    }
    generateAttacks() {
        return [
            ...attack_1.NUMBER_ATTACKS.COMMON
        ];
    }
}
exports.NumberPayload = NumberPayload;
