"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Joi = require("@hapi/joi");
const alternatives_payload_1 = require("./alternatives-payload");
const array_payload_1 = require("./array-payload");
const boolean_payload_1 = require("./boolean-payload");
const number_payload_1 = require("./number-payload");
const object_payload_1 = require("./object-payload");
const string_payload_1 = require("./string-payload");
const unknown_payload_1 = require("./unknown-payload");
const valid_payload_1 = require("./valid-payload");
function generatePayload(unknownSchema) {
    if (!Joi.isSchema(unknownSchema)) {
        throw new Error('No schema given');
    }
    const schema = unknownSchema;
    // eslint-disable-next-line no-extra-parens
    if (schema['_valids']) {
        return new valid_payload_1.ValidPayload().buildFromSchema(schema);
    }
    if (schema.type === 'boolean') {
        return new boolean_payload_1.BooleanPayload().buildFromSchema();
    }
    if (schema.type === 'string') {
        return new string_payload_1.StringPayload().buildFromSchema(schema);
    }
    if (schema.type === 'alternatives') {
        return new alternatives_payload_1.AltenativesPayload().buildFromSchema(schema);
    }
    if (schema.type === 'number') {
        return new number_payload_1.NumberPayload().buildFromSchema(schema);
    }
    if (schema.type === 'array') {
        return new array_payload_1.ArrayPayload().buildFromSchema(schema);
    }
    if (schema.type === 'object') {
        return new object_payload_1.ObjectPayload().buildFromSchema(schema);
    }
    return new unknown_payload_1.UnknownPayload();
}
exports.generatePayload = generatePayload;
